==> pycompileo-1.1.5.tar.gz: pycompileo-1.1.5/pycompileo/obfuscation/multiversion_obfuscate.py <==
import os
import sys
from ..compilation import compile


INIT_LOADER = \
'''
import sys
import shutil
import os

PWD = os.path.abspath(os.path.dirname(__file__))

def get_python_version():
    return str(sys.version_info.major) + '-' + str(sys.version_info.minor)

def flood_here(source_folder):
    for root, dirs, files in os.walk(source_folder):
        for file in files:
            source_file = os.path.join(root, file)
            
            relative_path = os.path.relpath(root, source_folder)
            destination_path = os.path.join(PWD, relative_path)
            
            os.makedirs(destination_path, exist_ok=True)
            shutil.copy(source_file, PWD)

flood_here(f'{PWD}/_CB/secret{get_python_version()}')

from . import second_init

for thing in dir(second_init):
    globals()[thing] = getattr(second_init, thing)
'''


def get_python_version():
    return str(sys.version_info.major) + '-' + str(sys.version_info.minor)


def multiversion_obfuscate_package(path: str, output_path=None, syspath: str = None, scaffoldy: bool = True, global_variables=None):
    if syspath:
        sys.path.insert(1, syspath)

    assert os.path.exists(path), Exception('Folder does not exist.')

    folder_name = os.path.basename(path)

    if not output_path:
        output_path = f'c{folder_name}'

    compile(folder_name, f"{output_path}/_CB/{folder_name}{get_python_version()}", rename_init='second_init.py', scaffoldy=scaffoldy, global_variables=global_variables)

    with open(f'{output_path}/__init__.py', 'w') as f:
        f.write(INIT_LOADER)

==> pycompileo-1.2.1.tar.gz: pycompileo-1.2.1/pycompileo/obfuscation/multiversion_obfuscate.py <==
import os
import sys
from ..compilation import compile


INIT_LOADER = \
'''import sys
import shutil
import os

PWD = os.path.abspath(os.path.dirname(__file__))


def get_python_version():
    return str(sys.version_info.major) + '-' + str(sys.version_info.minor)


def flood_here(source_folder):
    for root, dirs, files in os.walk(source_folder):
        for file in files:
            source_file = os.path.join(root, file)

            relative_path = os.path.relpath(root, source_folder)
            destination_path = os.path.join(PWD, relative_path)

            os.makedirs(destination_path, exist_ok=True)
            shutil.copy(source_file, os.path.join(destination_path, file))


flood_here(f'{PWD}/_CB/secret{get_python_version()}')

from . import second_init

for thing in dir(second_init):
    globals()[thing] = getattr(second_init, thing)
'''


def get_python_version():
    return str(sys.version_info.major) + '-' + str(sys.version_info.minor)


def multiversion_obfuscate_package(path: str, output_path=None, syspath: str = None, scaffoldy: bool = True, global_variables=None):
    if syspath:
        sys.path.insert(1, syspath)

    assert os.path.exists(path), Exception('Folder does not exist.')

    folder_name = os.path.basename(path)

    if not output_path:
        output_path = f'c{folder_name}'

    compile(folder_name, f"{output_path}/_CB/{folder_name}{get_python_version()}", rename_init='second_init.py', scaffoldy=scaffoldy, global_variables=global_variables)

    with open(f'{output_path}/__init__.py', 'w') as f:
        f.write(INIT_LOADER)
